import string

from cStringIO import StringIO

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.CMFCorePermissions import ManagePortal

from Products.HiddenGecko import skin_globals


skinFolders = ('gecko_images',
               'gecko_styles',
               'gecko_templates',
               'gecko_portlets',
               'gecko_scripts',
               )
               
skinName = 'HiddenGecko'
baseSkin = 'Plone Default'

stylesheets = (
        {'css': 'gecko.css', 'media': 'screen'},
        )

stylesheetCondition = "python:request.get(here.portal_skins.getRequestVarname(), here.portal_skins.getDefaultSkin()) == '%s'" % skinName


def setupSkin(self, out):
    """Adds skin if does not already exist."""
    skinsTool = getToolByName(self, 'portal_skins')
    
    addDirectoryViews(skinsTool, 'skins', skin_globals)
    print >> out, "Added directory views to portal_skins."
       
    if skinName not in skinsTool.getSkinSelections():
        path = skinsTool.getSkinPath(baseSkin)
        path = map(string.strip, string.split(path,','))
        
        for skinFolder in skinFolders:
            if skinFolder not in path:
                try: 
                    path.insert(path.index('custom') + 1, skinFolder)
                except ValueError:
                    path.append(skinFolder)
    
        path = string.join(path, ', ')    
        skinsTool.addSkinSelection(skinName, path)
    else:
        print >> out, 'Skin already exists, leaving it alone.'
  

def removeSkin(self, out):
    """Removes skin."""
    skinsTool = getToolByName(self, 'portal_skins')
    
    # Revert to 'Plone Default' if the current skin is the default
    if self.portal_skins.getDefaultSkin() == skinName:
        self.portal_skins.default_skin = 'Plone Default'

    # Delete the property which holds the skin
    if skinName in skinsTool.getSkinSelections():
        skinsTool.manage_skinLayers(del_skin = 1, chosen = (skinName,))


def registerStylesheets(self, out):
    """Register stylesheets with the css registry."""
    csstool = getToolByName(self, 'portal_css')

    for stylesheet in stylesheets:
        csstool.registerStylesheet(
                stylesheet['css'],
                media=stylesheet['media'],
                expression=stylesheetCondition,
                rendering='import')

    print >> out, "Registered stylesheets."


def unregisterStylesheets(self, out):
    """Remove registration of stylesheets from the css registry."""
    csstool = getToolByName(self, 'portal_css')

    for stylesheet in stylesheets:
        csstool.unregisterResource(stylesheet['css'])

    print >> out, "Remove registeration of stylesheets."


def install(self):
    """Install skin and registered css."""
    out = StringIO()
    setupSkin(self, out)
    registerStylesheets(self, out)
    print >> out, 'Installation completed.'
    return out.getvalue()


def uninstall(self):
    """Un-install skin and registered css."""
    out = StringIO()
    unregisterStylesheets(self, out)
    removeSkin(self, out)

    print >> out, 'Un-installation completed.'
    return out.getvalue()
